@@ -44,7 +44,7 @@ class Paste:
         ...
 
     async def go(self, content: Any) -> str:
-        async with self.__session.post(self.__url, data=content) as r:
+        async with self.__session.post(self.__url, json=content) as r:
             content_data = await r.json()
             url = self.url_map[self.__name]
             if self.__name == "stashbin":
@@ -64,6 +64,8 @@ class Misc(plugin.Plugin):
         """Display ID's"""
         msg = ctx.msg.reply_to_message or ctx.msg
         out_str = f"👥 **Chat ID :** `{(msg.forward_from_chat or msg.chat).id}`\n"
+        if msg.is_topic_message:
+            out_str += f"🗨️ **Topic ID :** `{msg.topics.id}`\n"
         out_str += f"💬 **Message ID :** `{msg.forward_from_message_id or msg.id}`\n"
         if msg.from_user:
             out_str += f"🙋‍♂️ **From User ID :** `{msg.from_user.id}`\n"
@@ -105,9 +107,9 @@ class Misc(plugin.Plugin):
 
         uris = {
             "-h": "https://hastebin.com/documents",
-            "-s": "http://stashbin.xyz/api/document",
+            "-s": "https://stashbin.xyz/api/document",
             "hastebin": "https://hastebin.com/documents",
-            "stashbin": "http://stashbin.xyz/api/document",
+            "stashbin": "https://stashbin.xyz/api/document",
             "spacebin": "https://spaceb.in/api/v1/documents/",
         }
         try:
